@@ -4,11 +4,20 @@ import re
 import sys
 
 from .base import ClosableResponse, EmptyResponse, Header, Method, Request, Response
-from .client import Client, setup
+from .client import Client, DefaultClient
 from .context import get_context, set_context
 from .deadline import Deadline
 from .delays_provider import constant_delays, linear_delays
 from .metrics import NOOP_METRICS_PROVIDER, MetricsProvider, NoopMetricsProvider
+from .pipeline import (
+    LowTimeoutRequestModule,
+    MetricsModule,
+    NextModuleFunc,
+    RequestModule,
+    TracingModule,
+    TransportModule,
+    build_pipeline,
+)
 from .priority import Priority
 from .request import delete, get, post, post_json, put, put_json
 from .request_strategy import (
@@ -26,6 +35,8 @@ from .request_strategy import (
     single_attempt_strategy,
 )
 from .response_classifier import DefaultResponseClassifier, ResponseClassifier, ResponseVerdict
+from .setup import setup, setup_v2
+from .tracing import NOOP_TRACER, NoopSpan, NoopTracer, Span, Tracer
 from .transport import Transport
 
 try:
@@ -42,7 +53,16 @@ try:
 except ImportError:
     pass
 
-__version__ = "0.1.8"
+try:
+    import opentelemetry.propagate
+    import opentelemetry.semconv
+    import opentelemetry.trace
+
+    from .opentelemetry import OpenTelemetryTracer
+except ImportError:
+    pass
+
+__version__ = "0.1.11"
 
 version = f"{__version__}, Python {sys.version}"
 
