@@ -1,5 +1,6 @@
 import abc
 import json
+import re
 from typing import Any, Callable, Dict, Iterable, List, Mapping, Optional, Tuple, Union
 
 import multidict
@@ -29,6 +30,9 @@ _MultiDict = Union[
     Mapping[Union[str, multidict.istr], str], multidict.CIMultiDictProxy[str], multidict.CIMultiDict[str]
 ]
 
+
+json_re = re.compile(r"^application/(?:[\w.+-]+?\+)?json", re.RegexFlag.IGNORECASE)
+
 PathParameters = Mapping[str, Any]
 QueryParameters = Union[Mapping[str, Any], Iterable[Tuple[str, Any]], _MultiDict]
 Headers = _MultiDict
@@ -74,7 +78,21 @@ class Request:
             url=self.url,
             path_parameters=self.path_parameters,
             query_parameters=self.query_parameters,
-            headers=multidict.CIMultiDictProxy[str](updated_headers),
+            headers=updated_headers,
+            body=self.body,
+        )
+
+    def extend_headers(self, headers: Headers) -> "Request":
+        updated_headers = (
+            multidict.CIMultiDict[str](self.headers) if self.headers is not None else multidict.CIMultiDict[str]()
+        )
+        updated_headers.extend(headers)
+        return Request(
+            method=self.method,
+            url=self.url,
+            path_parameters=self.path_parameters,
+            query_parameters=self.query_parameters,
+            headers=updated_headers,
             body=self.body,
         )
 
@@ -125,6 +143,14 @@ class Response(abc.ABC):
     def is_server_error(self) -> bool:
         return 500 <= self.status < 600
 
+    @property
+    def content_type(self) -> Optional[str]:
+        return self.headers.get(Header.CONTENT_TYPE)
+
+    @property
+    def is_json(self) -> bool:
+        return bool(json_re.match(self.content_type or ""))
+
 
 class ClosableResponse(Response, Closable):
     __slots__ = ()
@@ -135,10 +161,11 @@ class ClosableResponse(Response, Closable):
 
 
 class EmptyResponse(ClosableResponse):
-    __slots__ = ("_status",)
+    __slots__ = ("_status", "_headers")
 
-    def __init__(self, *, status: int):
+    def __init__(self, *, status: int, headers: multidict.CIMultiDictProxy[str] = EMPTY_HEADERS):
         self._status = status
+        self._headers = headers
 
     @property
     def status(self) -> int:
@@ -146,7 +173,7 @@ class EmptyResponse(ClosableResponse):
 
     @property
     def headers(self) -> multidict.CIMultiDictProxy[str]:
-        return EMPTY_HEADERS
+        return self._headers
 
     async def json(
         self,
